import { Box, Button } from "@mui/material";
import { convertFileSrc } from "@tauri-apps/api/tauri";
import { useEffect, useState } from "react";
import { useSettings } from "../../contexts/SettingsContext";
import { FooterBar } from "../FooterBar/FooterBar";
import { HeaderBar } from "../HeaderBar/HeaderBar";

export const Layout = () => {
  const { settings } = useSettings();

  const [imageUrl, setImageUrl] = useState<string | null>(null);

  const setBackground = async (filePath: string) => {
    const assetUrl = convertFileSrc(filePath);
    setImageUrl(assetUrl);
  };

  useEffect(() => {
    setBackground(settings.background.background_image_path);
  }, [settings.background.background_image_path]);

  return (
    <Box
      sx={{
        // Use the URL function for background images
        backgroundColor: settings.background.background_color,
        backgroundImage: settings.background.background_image_path ? `url(${imageUrl})` : "",
        backgroundSize: "cover",
        backgroundPosition: "center",
        backgroundRepeat: "no-repeat",
        display: "flex",
        flexDirection: "column",
        height: "100vh",
      }}
    >
      <HeaderBar />
      <Box
        sx={{
          display: "flex",
          flexGrow: 1,
          overflow: "auto",
        }}
      >
        <Box>
          <Button
            onClick={() => {
              console.log(imageUrl);
            }}
          >
            set background
          </Button>
        </Box>
      </Box>
      <FooterBar />
    </Box>
  );
};
